EXPORTS
	_ZN10TCisReader13FindReadTupleEhR5TDes8j @ 1 NONAME ; TCisReader::FindReadTuple(unsigned char, TDes8&, unsigned int)
	_ZN10TCisReader14FindReadConfigER13TPcCardConfig @ 2 NONAME ; TCisReader::FindReadConfig(TPcCardConfig&)
	_ZN10TCisReader14FindReadRegionE14TPccdSocketVccR13TPcCardRegionh @ 3 NONAME ; TCisReader::FindReadRegion(TPccdSocketVcc, TPcCardRegion&, unsigned char)
	_ZN10TCisReader7RestartEv @ 4 NONAME ; TCisReader::Restart()
	_ZN10TCisReader9ReadTupleER5TDes8 @ 5 NONAME ; TCisReader::ReadTuple(TDes8&)
	_ZN10TCisReader9SelectCisEii @ 6 NONAME ; TCisReader::SelectCis(int, int)
	_ZN10TCisReaderC1Ev @ 7 NONAME ; TCisReader::TCisReader()
	_ZN10TCisReaderC2Ev @ 8 NONAME ; TCisReader::TCisReader()
	_ZN11DPBusSocket10InCriticalEv @ 9 NONAME ; DPBusSocket::InCritical()
	_ZN11DPBusSocket12SocketFromIdEi @ 10 NONAME ; DPBusSocket::SocketFromId(int)
	_ZN11DPBusSocket13EndInCriticalEv @ 11 NONAME ; DPBusSocket::EndInCritical()
	_ZN11DPBusSocket16ForceMediaChangeEv @ 12 NONAME ; DPBusSocket::ForceMediaChange()
	_ZN11DPBusSocket17PowerDownCompleteEv @ 13 NONAME ; DPBusSocket::PowerDownComplete()
	_ZN11DPBusSocket21RequestAsyncPowerDownEv @ 14 NONAME ; DPBusSocket::RequestAsyncPowerDown()
	_ZN11DPBusSocket23DeltaCurrentConsumptionEi @ 15 NONAME ; DPBusSocket::DeltaCurrentConsumption(int)
	_ZN11DPBusSocket23PowerUpSequenceCompleteEi @ 16 NONAME ; DPBusSocket::PowerUpSequenceComplete(int)
	_ZN11DPBusSocket3AddEP13TPBusCallBack @ 17 NONAME ; DPBusSocket::Add(TPBusCallBack*)
	_ZN11DPBusSocket5PanicENS_6TPanicE @ 18 NONAME ; DPBusSocket::Panic(DPBusSocket::TPanic)
	_ZN11DPBusSocket7PowerUpEv @ 19 NONAME ; DPBusSocket::PowerUp()
	_ZN11RPccdWindow12SetupChunkHwEj @ 20 NONAME ; RPccdWindow::SetupChunkHw(unsigned int)
	_ZN11RPccdWindow13LinearAddressEv @ 21 NONAME ; RPccdWindow::LinearAddress()
	_ZN11RPccdWindow5CloseEv @ 22 NONAME ; RPccdWindow::Close()
	_ZN11RPccdWindow6CreateEP13DPcCardSocket9TPccdChnk16TPccdAccessSpeedj @ 23 NONAME ; RPccdWindow::Create(DPcCardSocket*, TPccdChnk, TPccdAccessSpeed, unsigned int)
	_ZN11RPccdWindowC1Ev @ 24 NONAME ; RPccdWindow::RPccdWindow()
	_ZN11RPccdWindowC2Ev @ 25 NONAME ; RPccdWindow::RPccdWindow()
	_ZN12DPBusPsuBase13DoTickServiceEv @ 26 NONAME ; DPBusPsuBase::DoTickService()
	_ZN12DPBusPsuBase25ReceiveVoltageCheckResultEi @ 27 NONAME ; DPBusPsuBase::ReceiveVoltageCheckResult(int)
	_ZN12DPBusPsuBase8DoCreateEv @ 28 NONAME ; DPBusPsuBase::DoCreate()
	_ZN12DPBusPsuBase8IsLockedEv @ 29 NONAME ; DPBusPsuBase::IsLocked()
	_ZN12DPBusPsuBase8SetStateE13TPBusPsuState @ 30 NONAME ; DPBusPsuBase::SetState(TPBusPsuState)
	_ZN13DPcCardSocket10VerifyCardER9TPccdType @ 31 NONAME ; DPcCardSocket::VerifyCard(TPccdType&)
	_ZN13DPcCardSocket13ReadConfigRegEiiRh @ 32 NONAME ; DPcCardSocket::ReadConfigReg(int, int, unsigned char&)
	_ZN13DPcCardSocket13ReleaseConfigEiP5DBase @ 33 NONAME ; DPcCardSocket::ReleaseConfig(int, DBase*)
	_ZN13DPcCardSocket13RequestConfigEiP5DBaseR13TPcCardConfigj @ 34 NONAME ; DPcCardSocket::RequestConfig(int, DBase*, TPcCardConfig&, unsigned int)
	_ZN13DPcCardSocket14WriteConfigRegEiih @ 35 NONAME ; DPcCardSocket::WriteConfigReg(int, int, unsigned char)
	_ZN13TPBusCallBack6RemoveEv @ 36 NONAME ; TPBusCallBack::Remove()
	_ZN13TPBusCallBack9SetSocketEi @ 37 NONAME ; TPBusCallBack::SetSocket(int)
	_ZN13TPBusCallBackC1EPFvPviES0_j @ 38 NONAME ; TPBusCallBack::TPBusCallBack(void (*)(void*, int), void*, unsigned int)
	_ZN13TPBusCallBackC1EPFvPviS0_S0_ES0_ @ 39 NONAME ; TPBusCallBack::TPBusCallBack(void (*)(void*, int, void*, void*), void*)
	_ZN13TPBusCallBackC1Ev @ 40 NONAME ; TPBusCallBack::TPBusCallBack()
	_ZN13TPBusCallBackC2EPFvPviES0_j @ 41 NONAME ; TPBusCallBack::TPBusCallBack(void (*)(void*, int), void*, unsigned int)
	_ZN13TPBusCallBackC2EPFvPviS0_S0_ES0_ @ 42 NONAME ; TPBusCallBack::TPBusCallBack(void (*)(void*, int, void*, void*), void*)
	_ZN13TPBusCallBackC2Ev @ 43 NONAME ; TPBusCallBack::TPBusCallBack()
	_ZN13TPcCardConfig19IsMachineCompatibleEii @ 44 NONAME ; TPcCardConfig::IsMachineCompatible(int, int)
	_ZN13TPcCardConfigC1Ev @ 45 NONAME ; TPcCardConfig::TPcCardConfig()
	_ZN13TPcCardConfigC2Ev @ 46 NONAME ; TPcCardConfig::TPcCardConfig()
	_ZN13TPcCardRegion19IsMachineCompatibleEi @ 47 NONAME ; TPcCardRegion::IsMachineCompatible(int)
	_ZN13TPcCardRegionC1Ev @ 48 NONAME ; TPcCardRegion::TPcCardRegion()
	_ZN13TPcCardRegionC2Ev @ 49 NONAME ; TPcCardRegion::TPcCardRegion()
	_ZN16DMediaChangeBase15DoorOpenServiceEv @ 50 NONAME ; DMediaChangeBase::DoorOpenService()
	_ZN16DMediaChangeBase17DoorClosedServiceEv @ 51 NONAME ; DMediaChangeBase::DoorClosedService()
	_ZN16DMediaChangeBase6CreateEv @ 52 NONAME ; DMediaChangeBase::Create()
	_ZN16DMediaChangeBaseC2Ei @ 53 NONAME ; DMediaChangeBase::DMediaChangeBase(int)
	_ZN26TPcCardControllerInterface6CreateEv @ 54 NONAME ; TPcCardControllerInterface::Create()
	_ZN9TPccdChnkC1E12TPccdMemTypemm @ 55 NONAME ; TPccdChnk::TPccdChnk(TPccdMemType, unsigned long, unsigned long)
	_ZN9TPccdChnkC1Ev @ 56 NONAME ; TPccdChnk::TPccdChnk()
	_ZN9TPccdChnkC2E12TPccdMemTypemm @ 57 NONAME ; TPccdChnk::TPccdChnk(TPccdMemType, unsigned long, unsigned long)
	_ZN9TPccdChnkC2Ev @ 58 NONAME ; TPccdChnk::TPccdChnk()
	_ZN9TPccdTypeC1Ev @ 59 NONAME ; TPccdType::TPccdType()
	_ZN9TPccdTypeC2Ev @ 60 NONAME ; TPccdType::TPccdType()
	_ZTI12DPBusPsuBase @ 61 NONAME ; typeinfo for DPBusPsuBase
	_ZTI16DMediaChangeBase @ 62 NONAME ; typeinfo for DMediaChangeBase
	_ZTV12DPBusPsuBase @ 63 NONAME ; vtable for DPBusPsuBase
	_ZTV16DMediaChangeBase @ 64 NONAME ; vtable for DMediaChangeBase
	_ZN11DPBusSocket9ControlIOEiPvS0_ @ 65 NONAME

